==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/space/messages/ro/base.php <==
<?php

return [
    '<strong>New</strong> spaces' => 'Spații <strong>Noi</strong>',
    'About' => 'Despre',
    'Accept' => 'Accept',
    'Admin' => 'Admin',
    'Archived' => 'Arhivat',
    'Cancel' => 'Anulează',
    'Close' => 'Închide',
    'Decline' => 'Respinge',
    'Default' => 'Implicit',
    'Delete' => 'Șterge',
    'Description' => 'Descriere',
    'Invite' => 'Invită',
    'Login' => 'Autentificare',
    'Members' => 'Membri',
    'Name' => 'Nume',
    'Public' => 'Public',
    'See all' => 'Vezi tot',
    'Send' => 'Trimite',
    'Settings' => 'Impostatii',
    'Sorting' => 'Sortare',
    'Spaces' => 'Spatii',
    'User not found!' => 'Utilizator negăsit!',
    'Users' => 'Utilizatori',
    'Visibility' => 'Vizibilitate',
    '<b>This space is still empty!</b>' => '',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Invite</strong> members' => '',
    '<strong>New</strong> member request' => '',
    '<strong>Request</strong> space membership' => '',
    '<strong>Space</strong> followers' => '',
    '<strong>Space</strong> members' => '',
    '<strong>Space</strong> menu' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Accept Invite' => '',
    'Add users without invitation' => '',
    'Administrator:' => '',
    'Administrators' => '',
    'Any' => '',
    'Application message' => '',
    'As owner you cannot revoke your membership!' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Color' => '',
    'Could not request membership!' => '',
    'Created At' => '',
    'Created By' => '',
    'Decline Invite' => '',
    'Default content visibility' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Done' => '',
    'Email addresses' => '',
    'Everyone can enter' => '',
    'Find Spaces by their description or by their tags' => '',
    'Follow' => '',
    'Followers' => '',
    'Following' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Homepage' => '',
    'Homepage (Guests)' => '',
    'Invite and request' => '',
    'Invite by email' => '',
    'Invites' => '',
    'Join' => '',
    'Join Policy' => '',
    'Last Visit' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Moderators' => '',
    'My Space List' => '',
    'My space summary' => '',
    'Neither..nor' => '',
    'New user by e-mail (comma separated)' => '',
    'New user?' => '',
    'Newest first' => '',
    'No results found!' => '',
    'No spaces found.' => '',
    'Oldest first' => '',
    'Only by invite' => '',
    'Originator User ID' => '',
    'Owner' => '',
    'Owner:' => '',
    'Pending' => '',
    'Pick users' => '',
    'Please shortly introduce yourself, to become a approved member of this workspace.' => '',
    'Please shortly introduce yourself, to become an approved member of this space.' => '',
    'Posts' => '',
    'Private' => '',
    'Private (Invisible)' => '',
    'Public (Members & Guests)' => '',
    'Public (Members only)' => '',
    'Public (Registered users only)' => '',
    'Request Message' => '',
    'Request workspace membership' => '',
    'Role' => '',
    'Search...' => '',
    'Select all registered users' => '',
    'Settings could not be saved!' => '',
    'Show all' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'Space' => '',
    'Space Visibility' => '',
    'Space directory' => '',
    'Space is invisible!' => '',
    'Status' => '',
    'Stream' => '',
    'Tags' => '',
    'There is no pending invite!' => '',
    'This action is only available for workspace members!' => '',
    'This user is already a member of this space.' => '',
    'This user is not a member of this space.' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Updated At' => '',
    'Updated By' => '',
    'Updated by' => '',
    'User \'{username}\' is already a member of this space!' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'Users has been invited.' => '',
    'Visible for all (members and guests)' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You are not allowed to join this space!' => '',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You cannot create private visible spaces!' => '',
    'You cannot create public visible spaces!' => '',
    'You need to login to view contents of this space!' => '',
    'Your request was successfully submitted to the space administrators.' => '',
    'Your request was successfully submitted to the workspace administrators.' => '',
    '{count} members' => '',
    '{email} is not valid!' => '',
];

==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/ro/base.php <==
<?php

return [
    '<strong>New</strong> spaces' => 'Spații <strong>Noi</strong>',
    'About' => 'Despre',
    'Accept' => 'Accept',
    'Admin' => 'Admin',
    'Archived' => 'Arhivat',
    'Cancel' => 'Anulează',
    'Close' => 'Închide',
    'Decline' => 'Respinge',
    'Default' => 'Implicit',
    'Delete' => 'Șterge',
    'Description' => 'Descriere',
    'Invite' => 'Invită',
    'Login' => 'Autentificare',
    'Members' => 'Membri',
    'Name' => 'Nume',
    'Public' => 'Public',
    'See all' => 'Vezi tot',
    'Send' => 'Trimite',
    'Settings' => 'Impostatii',
    'Sorting' => 'Sortare',
    'Spaces' => 'Spatii',
    'User not found!' => 'Utilizator negăsit!',
    'Users' => 'Utilizatori',
    'Visibility' => 'Vizibilitate',
    '<b>This space is still empty!</b>' => '',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Invite</strong> members' => '',
    '<strong>New</strong> member request' => '',
    '<strong>Request</strong> Membership' => '',
    '<strong>Space</strong> followers' => '',
    '<strong>Space</strong> members' => '',
    '<strong>Space</strong> menu' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Accept Invite' => '',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '',
    'Add users without invitation' => '',
    'Administrator:' => '',
    'Administrators' => '',
    'Any' => '',
    'As owner you cannot revoke your membership!' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Color' => '',
    'Could not request membership!' => '',
    'Created At' => '',
    'Created By' => '',
    'Decline Invite' => '',
    'Default content visibility' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Done' => '',
    'Email addresses' => '',
    'Everyone can enter' => '',
    'Find Spaces by their description or by their tags' => '',
    'Follow' => '',
    'Followers' => '',
    'Following' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Homepage' => '',
    'Homepage (Guests)' => '',
    'I want to become a member because...' => '',
    'Invite and request' => '',
    'Invite by email' => '',
    'Invites' => '',
    'Join' => '',
    'Join Policy' => '',
    'Last Visit' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Moderators' => '',
    'My Space List' => '',
    'My space summary' => '',
    'Neither..nor' => '',
    'New user by e-mail (comma separated)' => '',
    'New user?' => '',
    'Newest first' => '',
    'No results found!' => '',
    'No spaces found.' => '',
    'Oldest first' => '',
    'Only by invite' => '',
    'Originator User ID' => '',
    'Owner' => '',
    'Owner:' => '',
    'Pending' => '',
    'Pick users' => '',
    'Posts' => '',
    'Private' => '',
    'Private (Invisible)' => '',
    'Public (Members & Guests)' => '',
    'Public (Members only)' => '',
    'Public (Registered users only)' => '',
    'Request Message' => '',
    'Role' => '',
    'Search...' => '',
    'Select all registered users' => '',
    'Settings could not be saved!' => '',
    'Show all' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'Space' => '',
    'Space Visibility' => '',
    'Space directory' => '',
    'Space is invisible!' => '',
    'Status' => '',
    'Stream' => '',
    'Tags' => '',
    'There is no pending invite!' => '',
    'This action is only available for workspace members!' => '',
    'This user is already a member of this space.' => '',
    'This user is not a member of this space.' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Updated At' => '',
    'Updated By' => '',
    'Updated by' => '',
    'User \'{username}\' is already a member of this space!' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'Users has been invited.' => '',
    'Visible for all (members and guests)' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You are not allowed to join this space!' => '',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You cannot create private visible spaces!' => '',
    'You cannot create public visible spaces!' => '',
    'You need to login to view contents of this space!' => '',
    'Your Message' => '',
    'Your request was successfully submitted to the space administrators.' => '',
    '{count} members' => '',
    '{email} is not valid!' => '',
];
